@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
 use crate::ffi::PyBytesObject;
-use crate::serialize::json::WriteExt;
 use pyo3_ffi::*;
 use std::os::raw::c_char;
 use std::ptr::NonNull;
@@ -94,6 +93,59 @@ impl std::io::Write for BytesWriter {
     }
 }
 
+#[allow(dead_code)]
+// hack based on saethlin's research and patch in https://github.com/serde-rs/json/issues/766
+pub trait WriteExt: std::io::Write {
+    #[inline]
+    fn as_mut_buffer_ptr(&mut self) -> *mut u8 {
+        std::ptr::null_mut()
+    }
+
+    #[inline]
+    fn reserve(&mut self, len: usize) {
+        let _ = len;
+    }
+
+    #[inline]
+    fn set_written(&mut self, len: usize) {
+        let _ = len;
+    }
+
+    #[inline]
+    fn write_str(&mut self, val: &str) -> std::result::Result<(), std::io::Error> {
+        let _ = val;
+        Ok(())
+    }
+
+    #[inline]
+    unsafe fn write_reserved_fragment(
+        &mut self,
+        val: &[u8],
+    ) -> std::result::Result<(), std::io::Error> {
+        let _ = val;
+        Ok(())
+    }
+
+    #[inline]
+    unsafe fn write_reserved_punctuation(
+        &mut self,
+        val: u8,
+    ) -> std::result::Result<(), std::io::Error> {
+        let _ = val;
+        Ok(())
+    }
+
+    #[inline]
+    unsafe fn write_reserved_indent(
+        &mut self,
+        len: usize,
+    ) -> std::result::Result<(), std::io::Error> {
+        let _ = len;
+        Ok(())
+    }
+}
+
+#[allow(dead_code)]
 impl WriteExt for &mut BytesWriter {
     #[inline(always)]
     fn as_mut_buffer_ptr(&mut self) -> *mut u8 {
